@@ -1,17 +1,19 @@
 from judgeval.data.example import Example, ExampleParams
-from judgeval.data.api_example import ProcessExample, create_process_example
+from judgeval.data.custom_example import CustomExample
 from judgeval.data.scorer_data import ScorerData, create_scorer_data
 from judgeval.data.result import ScoringResult, generate_scoring_result
-from judgeval.data.ground_truth import GroundTruthExample
+from judgeval.data.trace import Trace, TraceSpan, TraceUsage
+
 
 __all__ = [
     "Example",
     "ExampleParams",
-    "ProcessExample",
-    "create_process_example",
+    "CustomExample",
     "ScorerData",
     "create_scorer_data",
     "ScoringResult",
     "generate_scoring_result",
-    "GroundTruthExample",
+    "Trace",
+    "TraceSpan",
+    "TraceUsage",
 ]
