@@ -1,8 +1,8 @@
 from judgeval.scorers.api_scorer import APIJudgmentScorer
 from judgeval.scorers.judgeval_scorer import JudgevalScorer
-from judgeval.scorers.prompt_scorer import PromptScorer, ClassifierScorer
-from judgeval.scorers.judgeval_scorers import (
-    ToolCorrectnessScorer,
+from judgeval.scorers.prompt_scorer import PromptScorer
+from judgeval.scorers.judgeval_scorers.api_scorers import (
+    ExecutionOrderScorer,
     JSONCorrectnessScorer,
     SummarizationScorer,
     HallucinationScorer,
@@ -11,12 +11,17 @@ from judgeval.scorers.judgeval_scorers import (
     ContextualPrecisionScorer,
     ContextualRecallScorer,
     AnswerRelevancyScorer,
-    ScorerWrapper,
     AnswerCorrectnessScorer,
-    Text2SQLScorer,
     ComparisonScorer,
     InstructionAdherenceScorer,
     GroundednessScorer,
+    DerailmentScorer,
+    ToolOrderScorer,
+    ClassifierScorer,
+    ToolDependencyScorer,
+)
+from judgeval.scorers.judgeval_scorers.classifiers import (
+    Text2SQLScorer,
 )
 
 __all__ = [
@@ -24,7 +29,7 @@ __all__ = [
     "JudgevalScorer",
     "PromptScorer",
     "ClassifierScorer",
-    "ToolCorrectnessScorer",
+    "ExecutionOrderScorer",
     "JSONCorrectnessScorer",
     "SummarizationScorer",
     "HallucinationScorer",
@@ -33,10 +38,12 @@ __all__ = [
     "ContextualPrecisionScorer",
     "ContextualRecallScorer",
     "AnswerRelevancyScorer",
-    "ScorerWrapper",
     "AnswerCorrectnessScorer",
     "Text2SQLScorer",
     "ComparisonScorer",
     "InstructionAdherenceScorer",
     "GroundednessScorer",
+    "DerailmentScorer",
+    "ToolOrderScorer",
+    "ToolDependencyScorer",
 ]
