@@ -2,18 +2,17 @@
 Infrastructure for executing evaluations of `Example`s using one or more `JudgevalScorer`s.
 """
 
-
 import asyncio
-import time 
+import time
 from tqdm.asyncio import tqdm_asyncio
 from typing import List, Union, Optional, Callable
 from rich.progress import Progress, SpinnerColumn, TextColumn
 
 from judgeval.data import (
-    Example, 
+    Example,
+    CustomExample,
     ScoringResult,
     generate_scoring_result,
-    create_process_example,
     create_scorer_data,
 )
 from judgeval.scorers import JudgevalScorer
@@ -22,6 +21,7 @@ from judgeval.common.exceptions import MissingTestCaseParamsError
 from judgeval.common.logger import example_logging_context, debug, error, warning, info
 from judgeval.judges import JudgevalJudge
 
+
 async def safe_a_score_example(
     scorer: JudgevalScorer,
     example: Example,
@@ -35,32 +35,42 @@ async def safe_a_score_example(
     Args:
         scorer (JudgevalScorer): The `JudgevalScorer` to use for scoring the example.
         example (Example): The `Example` to be scored.
-        
-        ignore_errors (bool): Whether to ignore errors during the evaluation. 
+
+        ignore_errors (bool): Whether to ignore errors during the evaluation.
         If set to false, any error will be raised and stop the evaluation.
         If set to true, the error will be stored in the `error` attribute of the `JudgevalScorer` and the `success` attribute will be set to False.
-        
-        skip_on_missing_params (bool): Whether to skip the test case if required parameters are missing. 
+
+        skip_on_missing_params (bool): Whether to skip the test case if required parameters are missing.
     """
     debug(f"Starting safe_a_score_example for example {example.example_id}")
     try:
         await scorer.a_score_example(example, _show_indicator=False)
         info(f"Successfully scored example {example.example_id}")
     except MissingTestCaseParamsError as e:
-        if skip_on_missing_params:  # Skip the example if the scorer requires parameters that are missing
-            with example_logging_context(example.timestamp, example.example_id):
-                warning(f"Skipping example {example.example_id} due to missing parameters")
+        if (
+            skip_on_missing_params
+        ):  # Skip the example if the scorer requires parameters that are missing
+            with example_logging_context(example.created_at, example.example_id):
+                warning(
+                    f"Skipping example {example.example_id} due to missing parameters"
+                )
             scorer.skipped = True
             return
         else:
-            if ignore_errors:  # Gracefully handle the error, does not stop the evaluation
+            if (
+                ignore_errors
+            ):  # Gracefully handle the error, does not stop the evaluation
                 scorer.error = str(e)
                 scorer.success = False
-                with example_logging_context(example.timestamp, example.example_id):
-                    warning(f"Ignoring errors for example {example.example_id}: {str(e)} due to missing parameters")
+                with example_logging_context(example.created_at, example.example_id):
+                    warning(
+                        f"Ignoring errors for example {example.example_id}: {str(e)} due to missing parameters"
+                    )
             else:  # Raise the error and stop the evaluation
-                with example_logging_context(example.timestamp, example.example_id):
-                    error(f"Stopping example {example.example_id}: {str(e)} due to missing parameters")
+                with example_logging_context(example.created_at, example.example_id):
+                    error(
+                        f"Stopping example {example.example_id}: {str(e)} due to missing parameters"
+                    )
                 raise
     except TypeError:  # in case a_score_example does not accept _show_indicator
         try:
@@ -68,27 +78,37 @@ async def safe_a_score_example(
         except MissingTestCaseParamsError as e:
             if skip_on_missing_params:
                 scorer.skipped = True
-                with example_logging_context(example.timestamp, example.example_id):
-                    warning(f"Skipping example {example.example_id} due to missing parameters")
+                with example_logging_context(example.created_at, example.example_id):
+                    warning(
+                        f"Skipping example {example.example_id} due to missing parameters"
+                    )
                 return
             else:
                 if ignore_errors:
                     scorer.error = str(e)
-                    scorer.success = False  
-                    with example_logging_context(example.timestamp, example.example_id):
-                        warning(f"Ignoring errors for example {example.example_id}: {str(e)} due to missing parameters")
+                    scorer.success = False
+                    with example_logging_context(
+                        example.created_at, example.example_id
+                    ):
+                        warning(
+                            f"Ignoring errors for example {example.example_id}: {str(e)} due to missing parameters"
+                        )
                 else:
-                    with example_logging_context(example.timestamp, example.example_id):
-                        error(f"Stopping example {example.example_id}: {str(e)} due to missing parameters")
+                    with example_logging_context(
+                        example.created_at, example.example_id
+                    ):
+                        error(
+                            f"Stopping example {example.example_id}: {str(e)} due to missing parameters"
+                        )
                     raise
     except Exception as e:
         if ignore_errors:
             scorer.error = str(e)
             scorer.success = False  # Assuming you want to set success to False
-            with example_logging_context(example.timestamp, example.example_id):
+            with example_logging_context(example.created_at, example.example_id):
                 warning(f"Ignoring errors for example {example.example_id}: {str(e)}")
         else:
-            with example_logging_context(example.timestamp, example.example_id):
+            with example_logging_context(example.created_at, example.example_id):
                 error(f"Stopping example {example.example_id}: {str(e)}")
             raise
 
@@ -121,15 +141,17 @@ async def score_task(
     """
     while not progress.finished:
         start_time = time.perf_counter()
-        
+
         try:
             await scorer.a_score_example(example, _show_indicator=False)
             finish_text = "Completed"
         except MissingTestCaseParamsError as e:
             if skip_on_missing_params:
                 scorer.skipped = True
-                with example_logging_context(example.timestamp, example.example_id):
-                    debug(f"Skipping example {example.example_id} due to missing parameters")
+                with example_logging_context(example.created_at, example.example_id):
+                    debug(
+                        f"Skipping example {example.example_id} due to missing parameters"
+                    )
                 return
             else:
                 if ignore_errors:
@@ -137,8 +159,12 @@ async def score_task(
                     scorer.success = False  # Override success
                     finish_text = "Failed"
                 else:
-                    with example_logging_context(example.timestamp, example.example_id):
-                        error(f"Stopping example {example.example_id}: {str(e)} due to missing parameters")
+                    with example_logging_context(
+                        example.created_at, example.example_id
+                    ):
+                        error(
+                            f"Stopping example {example.example_id}: {str(e)} due to missing parameters"
+                        )
                     raise
         except TypeError:
             try:
@@ -147,8 +173,12 @@ async def score_task(
             except MissingTestCaseParamsError as e:
                 if skip_on_missing_params:
                     scorer.skipped = True
-                    with example_logging_context(example.timestamp, example.example_id):
-                        debug(f"Skipping example {example.example_id} due to missing parameters")
+                    with example_logging_context(
+                        example.created_at, example.example_id
+                    ):
+                        debug(
+                            f"Skipping example {example.example_id} due to missing parameters"
+                        )
                     return
                 else:
                     if ignore_errors:
@@ -156,18 +186,24 @@ async def score_task(
                         scorer.success = False  # Override success
                         finish_text = "Failed"
                     else:
-                        with example_logging_context(example.timestamp, example.example_id):
-                            error(f"Stopping example {example.example_id}: {str(e)} due to missing parameters")
+                        with example_logging_context(
+                            example.created_at, example.example_id
+                        ):
+                            error(
+                                f"Stopping example {example.example_id}: {str(e)} due to missing parameters"
+                            )
                         raise
         except Exception as e:
             if ignore_errors:
                 scorer.error = str(e)
                 scorer.success = False  # Override success
                 finish_text = "Failed"
-                with example_logging_context(example.timestamp, example.example_id):
-                    warning(f"Ignoring errors for example {example.example_id}: {str(e)}")
+                with example_logging_context(example.created_at, example.example_id):
+                    warning(
+                        f"Ignoring errors for example {example.example_id}: {str(e)}"
+                    )
             else:
-                with example_logging_context(example.timestamp, example.example_id):
+                with example_logging_context(example.created_at, example.example_id):
                     error(f"Stopping example {example.example_id}: {str(e)}")
                 raise
 
@@ -213,9 +249,7 @@ async def score_with_indicator(
             tasks = []
             for scorer in scorers:
                 task_id = progress.add_task(
-                    description=scorer_console_msg(
-                        scorer, async_mode=True
-                    ),
+                    description=scorer_console_msg(scorer, async_mode=True),
                     total=100,
                 )  # Add task to progress bar
                 tasks.append(
@@ -231,9 +265,7 @@ async def score_with_indicator(
             await asyncio.gather(*tasks)
     else:
         tasks = [
-            safe_a_score_example(
-                scorer, example, ignore_errors, skip_on_missing_params
-            )
+            safe_a_score_example(scorer, example, ignore_errors, skip_on_missing_params)
             for scorer in scorers
         ]
 
@@ -241,9 +273,9 @@ async def score_with_indicator(
 
 
 async def a_execute_scoring(
-    examples: List[Example],
+    examples: Union[List[Example], List[CustomExample]],
     scorers: List[JudgevalScorer],
-    model: Optional[Union[str, List[str], JudgevalJudge]] = None,
+    model: Optional[Union[str, List[str], JudgevalJudge]] = "gpt-4.1",
     ignore_errors: bool = True,
     skip_on_missing_params: bool = True,
     show_indicator: bool = True,
@@ -257,7 +289,7 @@ async def a_execute_scoring(
     Each `Example` will be evaluated by all of the `JudgevalScorer`s in the `scorers` list.
 
     Args:
-        examples (List[Example]): A list of `Example` objects to be evaluated.
+        examples (Union[List[Example], List[CustomExample]]): A list of `Example` objects to be evaluated.
         scorers (List[JudgevalScorer]): A list of `JudgevalScorer` objects to evaluate the examples.
         model (Union[str, List[str], JudgevalJudge]): The model to use for evaluation.
         ignore_errors (bool): Whether to ignore errors during evaluation.
@@ -271,29 +303,32 @@ async def a_execute_scoring(
     Returns:
         List[ScoringResult]: A list of `ScoringResult` objects containing the evaluation results.
     """
+
     semaphore = asyncio.Semaphore(max_concurrent)
 
     async def execute_with_semaphore(func: Callable, *args, **kwargs):
-        try:
-            async with semaphore:
+        async with semaphore:
+            try:
                 return await func(*args, **kwargs)
-        except Exception as e:
-            error(f"Error executing function: {e}")
-            if kwargs.get('ignore_errors', False):
-                # Return None when ignoring errors
-                return None
-            raise
+            except Exception as e:
+                print(f"Error executing function: {e}")
+                if kwargs.get("ignore_errors", False):
+                    # Simply return None when ignoring errors, as expected by the test
+                    return None
+                # If we're not ignoring errors, propagate the exception
+                raise
 
     if verbose_mode is not None:
         for scorer in scorers:
             scorer.verbose_mode = verbose_mode
 
-    # Add model to scorers 
+    # Add model to scorers
     for scorer in scorers:
         scorer._add_model(model)
 
     scoring_results: List[ScoringResult] = [None for _ in examples]
     tasks = []
+    cloned_scorers: List[JudgevalScorer]
 
     if show_indicator and _use_bar_indicator:
         with tqdm_asyncio(
@@ -303,24 +338,22 @@ async def a_execute_scoring(
             bar_format="{desc}: |{bar}|{percentage:3.0f}% ({n_fmt}/{total_fmt}) [Time Taken: {elapsed}, {rate_fmt}{postfix}]",
         ) as pbar:
             for i, ex in enumerate(examples):
-                with example_logging_context(ex.timestamp, ex.example_id):
+                with example_logging_context(ex.created_at, ex.example_id):
                     debug(f"Starting scoring for example {ex.example_id}")
                     debug(f"Input: {ex.input}")
                     debug(f"Using {len(scorers)} scorers")
                     for scorer in scorers:
                         debug(f"Using scorer: {type(scorer).__name__}")
-                        if hasattr(scorer, 'threshold'):
+                        if hasattr(scorer, "threshold"):
                             debug(f"Scorer threshold: {scorer.threshold}")
-                        if hasattr(scorer, 'model'):
+                        if hasattr(scorer, "model"):
                             debug(f"Scorer model: {type(scorer.model).__name__}")
-                if isinstance(ex, Example):
+                if isinstance(ex, Example) or isinstance(ex, CustomExample):
                     if len(scorers) == 0:
                         pbar.update(1)
                         continue
-                    
-                    cloned_scorers: List[JudgevalScorer] = clone_scorers(
-                        scorers
-                    )
+
+                    cloned_scorers = clone_scorers(scorers)
                     task = execute_with_semaphore(
                         func=a_eval_examples_helper,
                         scorers=cloned_scorers,
@@ -339,13 +372,11 @@ async def a_execute_scoring(
             await asyncio.gather(*tasks)
     else:
         for i, ex in enumerate(examples):
-            if isinstance(ex, Example):
+            if isinstance(ex, Example) or isinstance(ex, CustomExample):
                 if len(scorers) == 0:
                     continue
 
-                cloned_scorers: List[JudgevalScorer] = clone_scorers(
-                    scorers
-                )
+                cloned_scorers = clone_scorers(scorers)
                 task = execute_with_semaphore(
                     func=a_eval_examples_helper,
                     scorers=cloned_scorers,
@@ -366,7 +397,7 @@ async def a_execute_scoring(
 
 async def a_eval_examples_helper(
     scorers: List[JudgevalScorer],
-    example: Example,
+    example: Union[Example, CustomExample],
     scoring_results: List[ScoringResult],
     score_index: int,
     ignore_errors: bool,
@@ -374,10 +405,10 @@ async def a_eval_examples_helper(
     show_indicator: bool,
     _use_bar_indicator: bool,
     pbar: Optional[tqdm_asyncio] = None,
-    ) -> None:
+) -> None:
     """
     Evaluate a single example asynchronously using a list of scorers.
-    
+
     Args:
         scorers (List[JudgevalScorer]): List of JudgevalScorer objects to evaluate the example.
         example (Example): The example to be evaluated.
@@ -391,6 +422,7 @@ async def a_eval_examples_helper(
     Returns:
         None
     """
+
     show_metrics_indicator = show_indicator and not _use_bar_indicator
 
     for scorer in scorers:
@@ -398,7 +430,6 @@ async def a_eval_examples_helper(
         scorer.error = None  # Reset scorer error
 
     # scoring the Example
-    process_example = create_process_example(example)  # Creates process example to track progress
     scoring_start_time = time.perf_counter()
     await score_with_indicator(
         scorers=scorers,
@@ -408,20 +439,27 @@ async def a_eval_examples_helper(
         show_indicator=show_metrics_indicator,
     )  # execute the scoring functions of each scorer on the example
 
-    # Now that all the scoring functions of each scorer have executed, we collect 
-    # the results and update the process example with the scorer data
+    # Now that all the scoring functions of each scorer have executed, we collect
+    # the results and update the ScoringResult with the scorer data
+    success = True
+    scorer_data_list = []
     for scorer in scorers:
         # At this point, the scorer has been executed and already contains data.
-        if getattr(scorer, 'skipped', False):
+        if getattr(scorer, "skipped", False):
             continue
-        scorer_data = create_scorer_data(scorer)  # Fetch scorer data from completed scorer evaluation
-        process_example.update_scorer_data(scorer_data)  # Update process example with the same scorer data
-          
-    test_end_time = time.perf_counter()
-    run_duration = test_end_time - scoring_start_time
-    
-    process_example.update_run_duration(run_duration)   # Update process example with execution time duration
-    scoring_results[score_index] = generate_scoring_result(process_example)  # Converts the outcomes of the executed test to a ScoringResult and saves it
+        scorer_data = create_scorer_data(
+            scorer
+        )  # Fetch scorer data from completed scorer evaluation
+        success = success and scorer_data.success
+        scorer_data_list.append(scorer_data)
+
+    scoring_end_time = time.perf_counter()
+    run_duration = scoring_end_time - scoring_start_time
+
+    scoring_result = generate_scoring_result(
+        example, scorer_data_list, run_duration, success
+    )
+    scoring_results[score_index] = scoring_result
 
     if pbar is not None:
         pbar.update(1)
